%% Default Parameter Probability Distributions
%
% Provides default parameter distributions for each model parameter, to be used
% for Latin hypercube sampling.
%
function [param_dists] = default_dists(regime)

    % load the default fixed, initial values of the model parameters
    % for use in building the default distributions.
    params = model_params();

    % the default (and hopefully sensible) parameter distributions
    % make sure this respects that all interventions are OFF by default

    % WARNING: Dc (and other diagnosis strategy parameters) may be
        % changed by calls to diagnosis_dists() or diagnosis_regime() and
        % changed from a distribution to constant. Check all m-files with
        % grep carefully.

    param_dists = struct( ...
        'omega', dist_beta(365, 90, 180, 730), ...
        'gamma', dist_beta(365 / 1.5, 50, 365 / 2.5, 365), ...
        'R0', dist_flat(1.2,1.5), ...
        'eta', dist_logflat(-3,-1), ...
        'frac_gp', dist_flat(0.2, 0.8), ...
        'delta', dist_beta(365 / 2.5, 12, 365 / 3, 365 / 2), ...
        'e_t', dist_beta(0.7, 0.1, 0.5, 0.9), ...
        'e_s', dist_beta(0.7, 0.1, 0.4, 1.0), ...
        'Dc', dist_logflat(3,5), ...
        'MaxAVtoTreat_Ph1', dist_logflat(3,5), ...
        'MaxAVtoContacts_Ph1', dist_logflat(3,5), ...
        'O', dist_flat(1e6,20e6) ...
        );

    if nargin > 0
        param_dists = diagnosis_dists(param_dists, regime);
    end
end
