%% Diagnosis-Specific Parameter Distributions
%
% param_dists = diagnosis_dists(param_dists, regime);
%
% Updates a set of parameter distributions in accordance with the constraints
% of the specified regime. Valid regime values are: 'syndromic', 'PCR',
% 'PoC (local)', 'PoC (lab)'.
%
function [param_dists] = diagnosis_dists(dists, regime)
    % copy the provided parameter distributions
    param_dists = struct(dists);
    % get the default parameter values for the given regime
    params = diagnosis_regime(model_params(), regime);
    % set the (constant) parameter distributions to the regime-specific values
    param_dists.Sn = dist_const(params.Sn);
    param_dists.Sp = dist_const(params.Sp);
    %param_dists.Dc = dist_const(params.Dc); % Don't override the sampling
    %of Dc under any circumstances
    param_dists.e_dt = dist_const(params.e_dt);
    param_dists.e_dp = dist_const(params.e_dp);
end
