%% Diagnosis Regime Parameters
%
%  params = diagnosis_regime(params, regime);
%
% Sets diagnosis parameters to appropriate values for a given diagnosis
% regime. Valid regime values are: 'syndromic', 'PCR', 'PoC (local)',
% 'PoC (lab)'. Parameters sigma and frac_gp are not affected.
%
function [paramset] = diagnosis_regime(params, regime)
    paramset = struct(params);
    if strcmp(regime, 'syndromic')
        paramset.Sn = 1.0;
        paramset.Sp = 0.0;
        %% Syndromic diagnosis is limited by the GP and ED capacities.
        paramset.Dc = params.cap_gp + params.cap_ed; % params.N;
        paramset.e_dt = 1.0;
        paramset.e_dp = 1.0;
    elseif strcmp(regime, 'PCR')
        paramset.Sn = 1.0;
        paramset.Sp = 1.0;
        %paramset.Dc = 1e4; % Don't overwrite the LHS sampled value.
        paramset.e_dt = 0.7;
        paramset.e_dp = 0.7;
    elseif strcmp(regime, 'PoC (local)')
        paramset.Sn = 0.56;
        paramset.Sp = 0.9;
        paramset.Dc = params.N; % essentially infinite capacity
        paramset.e_dt = 1.0;
        paramset.e_dp = 1.0;
    elseif strcmp(regime, 'PoC (lab)')
        paramset.Sn = 0.56;
        paramset.Sp = 0.9;
        paramset.Dc = 1e5; % estimate
        paramset.e_dt = 0.7;
        paramset.e_dp = 0.7;
    else
        error('Invalid diagnosis regime: "%s"', regime);
    end
end
