%%BURDEN_TABLE   Calculate healthcare burdens for every scenario and strategy.
%
%   [table] = burden_table(filename);
%
% See also: BURDEN
function [tbl] = burden_table(filename)
    if (nargin < 1)
        filename = 'burden_table.ssv';
    end

    num_scen = 7;
    %% Ignore the final strategy (no AVs) since some of the statistics will
    %% compare the chosen strategy against this baseline.
    %% num_strat = 5;
    num_strat = 6;
    tbl = cell(num_scen, num_strat);
    for S = 1:num_scen
        for A = 1:num_strat
            tbl{S, A} = burden(S, A - 1);
        end
    end

    get_tbl = @(sc, st) tbl{sc, st + 1}.value;
    tbls = [get_tbl(1, 0); get_tbl(1, 1); get_tbl(1, 2); ...
            get_tbl(1, 3); get_tbl(1, 4); get_tbl(1, 5); ...
            get_tbl(2, 0); get_tbl(2, 1); get_tbl(2, 2); ...
            get_tbl(2, 3); get_tbl(2, 4); get_tbl(2, 5); ...
            get_tbl(3, 0); get_tbl(3, 1); get_tbl(3, 2); ...
            get_tbl(3, 3); get_tbl(3, 4); get_tbl(3, 5); ...
            get_tbl(4, 0); get_tbl(4, 1); get_tbl(4, 2); ...
            get_tbl(4, 3); get_tbl(4, 4); get_tbl(4, 5); ...
            get_tbl(5, 0); get_tbl(5, 1); get_tbl(5, 2); ...
            get_tbl(5, 3); get_tbl(5, 4); get_tbl(5, 5); ...
            get_tbl(6, 0); get_tbl(6, 1); get_tbl(6, 2); ...
            get_tbl(6, 3); get_tbl(6, 4); get_tbl(6, 5); ...
            get_tbl(7, 0); get_tbl(7, 1); get_tbl(7, 2); ...
            get_tbl(7, 3); get_tbl(7, 4); get_tbl(7, 5);];
    name_lst = tbl{1,1}.name';
    name_col = repmat(name_lst, num_scen * num_strat, 1);
    ctbl = [name_col, num2cell(tbls)];
    titles = {'stat', 'scenario', 'strategy', ...
              'median', 'CI05', 'CI95', 'mean'};
    tbl = [titles; ctbl];
    fileID = fopen(filename, 'w');
    formatSpec = '%s %f %f %f %f %d %d\n';
    [nrows,ncols] = size(tbl);
    fprintf(fileID, '%s %s %s %s %s %s %s\n', tbl{1, :});
    for row = 2:nrows
        fprintf(fileID, formatSpec, tbl{row, :});
    end
    fclose(fileID);
end
