function [hc] = default_healthcare()
    %% Define the healthcare-related parameters in a single record.
    %% The treatment priority: HCW, High-Risk, Children, Elderly, General.
    hc = struct('priority', [4, 3, 1, 2, 5], ...
                'mild_to_GP', 0.8, ...
                'early_rx_sev_to_mild', [0.0, 0.16, 0.50, 0.16, 0.16], ...
                'early_rx_sev_propn', 0.5, ...
                'hosp_rx_to_ICU_base', 0.125, ...
                'hosp_rx_to_ICU_rr', [1, 1, 2, 1, 1], ...
                'hosp_rx_ICU_RoD_base', 0.4, ...
                'hosp_rx_ICU_RoD_rr', [1, 1, 1.5, 1, 1], ...
                'hosp_to_ICU_rr', sqrt([1.33, 1.33, 2.5, 1.33, 1.33]), ...
                'hosp_ICU_RoD_rr', sqrt([1.33, 1.33, 2.5, 1.33, 1.33]), ...
                'LoS_ICU', 10, ...
                'LoS_Ward', 5, ...
                'cap_GP', 171000, ...
                'cap_ED', 8900, ...
                'cap_Ward', 27600, ...
                'cap_ICU', 1000);
    hc.mild_to_ED = 1 - hc.mild_to_GP;
    hc.hosp_rx_to_ICU = hc.hosp_rx_to_ICU_base .* hc.hosp_rx_to_ICU_rr;
    hc.hosp_rx_ICU_RoD = hc.hosp_rx_ICU_RoD_base .* hc.hosp_rx_ICU_RoD_rr;
    hc.hosp_to_ICU = hc.hosp_rx_to_ICU .* hc.hosp_to_ICU_rr;
    hc.hosp_ICU_RoD = hc.hosp_rx_ICU_RoD .* hc.hosp_ICU_RoD_rr;
    %% There is no evidence that AVs have beneficial effects for children.
    hc.hosp_rx_to_ICU(1) = hc.hosp_to_ICU(1);
    hc.hosp_rx_ICU_RoD(1) = hc.hosp_ICU_RoD(1);
end
