function [incidence] = epi_curve(strategy)
    if (nargin < 1)
        strategy = 5;
    end

    num_days = 366;
    num_scen = 7;
    num_rows = num_days * num_scen;
    num_cols = 6;
    incidence = zeros(num_rows, num_cols);

    for scenario = 1:7
        exp_name = sprintf('Scenario%d_AVstrategy%d', scenario, strategy);
        data = most_recent(exp_name);
        car_general = squeeze(data.lhs_data.stats(1, :, 10));
        car_median = median(car_general);
        car_05ci = quantile(car_general, 0.05);
        car_95ci = quantile(car_general, 0.95);
        car_median_diff = abs(car_general - car_median);
        mdn_mask = car_median_diff == min(car_median_diff);
        car_05ci_diff = abs(car_general - car_05ci);
        c05_mask = car_05ci_diff == min(car_05ci_diff);
        car_95ci_diff = abs(car_general - car_95ci);
        c95_mask = car_95ci_diff == min(car_95ci_diff);
        ix_mdn = find(mdn_mask, 1);
        ix_c05 = find(c05_mask, 1);
        ix_c95 = find(c95_mask, 1);
        ixs = [ix_mdn ix_c05 ix_c95];

        strata_incidence = get_daily_incidence(data, ixs);
        scenario_incidence = squeeze(sum(strata_incidence, 2));

        rix0 = num_days * (scenario - 1);
        rixs = rix0 + 1:rix0 + 366;
        incidence(rixs, 1) = scenario;
        incidence(rixs, 2) = strategy;
        incidence(rixs, 3) = 0:num_days - 1;
        incidence(rixs, 4:6) = scenario_incidence';

        %% out_name = sprintf('daily_presentations_%1d%1d.ssv', scenario, ...
        %%                    strategy);
        %% dlmwrite(out_name, scenario_incidence', 'delimiter', ' ');
    end
end

%%
%% Calculate the daily incidence of presenting cases.
%%
function [di_net] = get_daily_incidence(data, ixs)
    stats = data.lhs_data.stats;
    layout = data.lhs_data.stat_layout;
    stat_names = fieldnames(layout);
    ix_di = 1;
    ix_dip = 1;
    ix_end = 1;
    for ix = 1:length(stat_names)
        name = stat_names{ix};
        stat_dims = layout.(name);
        stat_sz = stat_dims(1);

        if (strcmp(name, 'DailyIncNP'))
            ix_dip = ix_dip + stat_sz;
            ix_end = ix_end + stat_sz;
        elseif (strcmp(name, 'DailyIncP'))
            ix_end = ix_end + stat_sz;
            break
        else
            ix_di = ix_di + stat_sz;
            ix_dip = ix_dip + stat_sz;
            ix_end = ix_end + stat_sz;
        end
    end

    %% Extract the daily incidence for each strata, distinguishing between
    %% cases that have and have not received post-exposure prophylaxis.
    di_np = stats(1, ixs, ix_di:ix_dip - 1);
    di_np = reshape(di_np, [length(ixs) layout.DailyIncNP(2:3)]);
    di_wp = stats(1, ixs, ix_dip:ix_end - 1);
    di_wp = reshape(di_wp, [length(ixs) layout.DailyIncP(2:3)]);
    %% Calculate the net daily incidence for each strata.
    di_net = di_np + di_wp;
end
