function [daily_inc] = get_presentations(scenario, strategy)
    exp_name = sprintf('Scenario%d_AVstrategy%d', scenario, strategy);
    data = most_recent(exp_name);
    stats = data.lhs_data.stats;
    smpls = data.lhs_data.parameter_samples;
    median_CARs = quantile(stats(1, :, 6:10), [0.5], 2);
    median_sz = size(median_CARs);
    median_CARs = reshape(median_CARs, median_sz(2), median_sz(3));
    mat_CARs = stats(1, :, 6:10);
    mat_sz = size(mat_CARs);
    mat_CARs = reshape(mat_CARs, mat_sz(2), mat_sz(3));
    diffs = mat_CARs - ones(size(mat_CARs)) * diag(median_CARs);
    sum_sqs = sum(diffs .* diffs, 2);
    [min_sum, min_ix] = min(sum_sqs);

    fprintf('Running simulation %d ...', min_ix);

    param_names = fieldnames(smpls);
    %% params = struct();
    params = struct(data.lhs_data.unsampled_params);
    for ix = 1:length(param_names)
        name = param_names{ix};
        p_vals = smpls.(name);
        ndim = length(size(p_vals));
        if (ndim == 2)
            sample = squeeze(p_vals(1, min_ix));
        elseif (ndim == 3)
            sample = squeeze(p_vals(1, min_ix, :));
        else
            throw(MException('get_sim_time_series', 'invalid sample'))
        end
        params.(name) = sample;
    end

    %% Print the sampled value of eta and exit.
    %% fprintf('%1d %1d %f\n', scenario, strategy, params.eta(1));
    %% daily_inc = 0;
    %% return

    %% Load the model definition.
    model = discrete_model();
    [time ps state evts] = single_simulation(model, params);
    fprintf(' done\n');

    %% Convert time from steps to days.
    steps_per_day = evts.timescale / 365;

    %% Extract the daily *presentation* incidence for each strata.
    day_ixs = steps_per_day * (0:365) + 1;
    daily_state = state(day_ixs, :);
    daily_cum_inc = daily_state(:, 136:140);
    daily_inc = daily_cum_inc(2:366, :) - daily_cum_inc(1:365, :);

    tbl_file = [exp_name '.csv'];
    fprintf('Saving to %s\n', tbl_file);
    strata = {'Children', 'Elderly', 'HighRisk', 'HCW', 'General'};
    inc_tbl = array2table(daily_inc, 'VariableNames', strata);
    writetable(inc_tbl, tbl_file);

end
