#!/bin/sh
##
## Run an LHS experiment.
##

## The default number of parallel workers.
N=16
## The MATLAB command-line options.
MATLAB_ARGS="-nodisplay -nosplash -nodesktop"

## Check whether to update the number of parallel workers.
if [ "$#" -ge 2 ] && [ "$1" = "-n" ]; then
    ## Ensure the provided value is a positive integer.
    if [ "$2" -eq "$2" ] 2> /dev/null && [ "$2" -gt 0 ]; then
        N="$2"
        shift 2
    else
        echo "ERROR: -n requires a positive integer"
        exit 2
    fi
fi

## Display a usage message and quit if the arguments are not valid.
if [ "$#" -ne 1 ]; then
    echo "USAGE: $(basename $0) [-n NUM_WORKERS] scenario_file.m"
    echo ""
    echo "Options:"
    echo "    -n NUM_WORKERS    Set the number of parallel workers"
    echo "                      Default: ${N}"
    echo ""
    exit 2
fi

## Check whether the script file exists in the same directory as this script.
SCRIPT=$(basename -- $1)
if [ ! -r "${SCRIPT}" ]; then
    echo "ERROR: can not read file '${SCRIPT}'"
    exit 2
fi

## Determine the name of the corresponding MATLAB function (remove the '.m').
FUNCTION=$(basename -- ${SCRIPT} .m)

## Ensure the working directory is the directory that contains this script.
OLD_WD=$(pwd)
cd $(dirname $0)

## Run the LHS experiment and terminate the MATLAB session.
echo matlab ${MATLAB_ARGS} -r "parpool(${N}); ${FUNCTION}; exit"

## Restore the previous working directory (probably unnecessary).
cd "${OLD_WD}"
