function summary(flu_scenario, av_strategy)
    try
        exp = sprintf('Scenario%d_AVstrategy%d', flu_scenario, av_strategy);
        [data, mat_file, full_path] = most_recent(exp);
    catch ME
        if strcmp(ME.identifier, 'most_recent: nth_last reduced to 0')
            fprintf('No output file for "%s"', exp);
            return
        else
            rethrow(ME);
        end
    end

    p = [0.05, 0.50, 0.95];
    AR_qtls = 100 * quantile(data.lhs_data.stats(1, :, 1:5), p, 2);
    CAR_qtls = 100 * quantile(data.lhs_data.stats(1, :, 6:10), p, 2);

    AR_mean = 100 * mean(data.lhs_data.stats(1, :, 1:5), 2);
    CAR_mean = 100 * mean(data.lhs_data.stats(1, :, 6:10), 2);

    AV_qtls = quantile(data.lhs_data.stats(1, :, 66), p, 2);
    AV_mean = mean(data.lhs_data.stats(1, :, 66), 2);

    strata = {'Children', 'Elderly', 'High-Risk', 'HCW', 'General'};
    fprintf('    Scenario %d    AV Strategy %d', flu_scenario, av_strategy);
    fprintf('    AV Doses    %9.1f (%9.1f, %9.1f) %9.1f\n', ...
            AV_qtls(1, 2, 1), AV_qtls(1, 1, 1), AV_qtls(1, 3, 1), ...
            AV_mean(1, 1, 1));
    for i = 1:5
        fprintf('%10s   AR (%%)  %5.2f (%5.2f, %5.2f) %5.2f', ...
                char(strata(i)), ...
                AR_qtls(1, 2, i), AR_qtls(1, 1, i), AR_qtls(1, 3, i), ...
                AR_mean(1, 1, i));
        fprintf('    CAR (%%)  %5.2f (%5.2f, %5.2f) %5.2f\n', ...
                CAR_qtls(1, 2, i), CAR_qtls(1, 1, i), CAR_qtls(1, 3, i), ...
                CAR_mean(1, 1, i));
    end
end
