%LONGEST_SEQN   Finds the longest sequence of ones in a vector.
%   The starting and ending indices of the sequence are returned, as is the
%   length of the sequence.
%
%   [ix_start, ix_end, seqn_len] = LONGEST_SEQN(vector);
%
%   VECTOR is a (column or row) vector, which must contain only ones and zeros.
%
%   IX_START is the index of the start of the longest sequence of ones.
%
%   IX_END is the index of the end of the longest sequence of ones.
%
%   SEQN_LEN is the length of the sequence of ones.
%
function [ix_start, ix_end, seqn_len] = longest_seqn(vector)
    % MPD Mon Nov 8 2010 to handle n*1 or 1*n vectors 
    sv=size(vector);
    if sv(1)==1
        vec=vector; % do nothing
    else
        vec=vector'; % transpose
    end;
    diffs = diff([0 vec 0]);
    starts = find(diffs == 1);
    ends = find(diffs == -1);
    [seqn_len, ix] = max(ends - starts);
    ix_start = starts(ix);
    ix_end = ends(ix) - 1;
end
