%% Initial Model State
%
% Calculates the initial state of the model; the state variables are
% collected into a single array.
%
function [state] = model_state(params)

n = length(params.pi);
% Exposed individuals
E_p_w = zeros(n,1);
E_np_w = params.I0.*(1./params.omega./(1./params.gamma+1./params.omega));
E_p_r = zeros(n,1);
E_np_r = zeros(n,1);

% Infected individuals
% Initially there is no treatment or prophylaxis, so every infected
% individual belongs to I_np_nt_w.

% Fix alpha_m
params.alpha_m = params.alpha_m';
alpha_np_w = params.eta + params.alpha_m .* (1 - params.eta);
I_p_w = zeros(n,1);
I_npt_w = zeros(n,1);
I_npnt_w = params.I0.*(1./params.gamma./(1./params.gamma+1./params.omega)) .* alpha_np_w;
I_p_r = zeros(n,1);
I_np_r = zeros(n,1);

% Asymptomatic infections
A_p_w = zeros(n,1);
A_np_w = params.I0.*(1./params.gamma./(1./params.gamma+1./params.omega)) .* (1 - alpha_np_w);
A_p_r = zeros(n,1);
A_np_r = zeros(n,1);

% Recovery from symptomatic infections
RI_p_w = zeros(n,1);
RI_np_w = zeros(n,1);
RI_p_r = zeros(n,1);
RI_np_r = zeros(n,1);

% Recovery from asymptomatic infections
RA_p_w = zeros(n,1);
RA_np_w = zeros(n,1);
RA_p_r = zeros(n,1);
RA_np_r = zeros(n,1);

% Cumulative incidence (account keeping)
CumInc = zeros(n,1);
% Cumulative incidence with prophylaxis (account keeping)
CumIncP = zeros(n,1);

% Contact classes
C_p_w = zeros(n,1);
C_np_w = (params.kappa'/365) * (I_npnt_w + A_np_w);
C_p_r = zeros(n,1);
C_np_r = zeros(n,1);

% Susceptible population
S = params.N.*params.pi - params.I0;
S_v = zeros(n,1);

% Drug stockpile
O_pPh1 = 0; % Used for prophylaxis in Contain
O_tPh1 = 0; % Used for treatment in Contain
O_pPh2 = 0; % Used for prophylaxis in Sustain
O_tPh2 = 0; % Used for treatment in Sustain
O_tSev = 0; % Used for treatment of severe cases
O_tMld = 0; % Used for treatment of mild cases
O_tWst = 0; % Used for treatment of mild non-flu cases

% Vaccinees
VaccineesFromS = zeros(n,1);
TotalVaccinees = zeros(n,1);

% State variable vector
state = [...
  S; S_v; C_p_w; C_np_w; C_p_r; C_np_r; E_p_w; E_np_w; E_p_r; E_np_r; ...
  I_p_w; I_npt_w; I_npnt_w; I_p_r; I_np_r; A_p_w; A_np_w; A_p_r; A_np_r; ...
  RI_p_w; RI_np_w; RI_p_r; RI_np_r; RA_p_w; RA_np_w; RA_p_r; RA_np_r; ...
  CumInc; CumIncP; params.O; O_pPh1; O_tPh1; O_pPh2; O_tPh2; O_tSev; O_tMld; O_tWst; ...
  VaccineesFromS; TotalVaccinees ...
];

end
